# Texy: A conservative text processing library

---

[![Python](https://github.com/mdmmn378/texy/actions/workflows/build-publish.yaml/badge.svg)](https://github.com/mdmmn378/texy/actions/workflows/build-publish.yaml)

> Do text processing without getting your hands dirty

## Installation

> `pip install texy`

## Example:

```py
from texy.pipelines import run_101
run_101(["💩🔙🙈🚘🚺🦷🦨🧒🏻🫸🕑🐠🧷🍈🐟🐡🦈🐬  <hello>what's up</hello>,"])
```
